@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package HTML::Widget::Factory;
 # ABSTRACT: churn out HTML widgets
-$HTML::Widget::Factory::VERSION = '0.203';
+$HTML::Widget::Factory::VERSION = '0.204';
 use Carp ();
 use Module::Load ();
 use MRO::Compat;
@@ -277,7 +277,7 @@ HTML::Widget::Factory - churn out HTML widgets
 
 =head1 VERSION
 
-version 0.203
+version 0.204
 
 =head1 SYNOPSIS
 
@@ -396,6 +396,30 @@ param that matches the passed name.
 
 Ricardo SIGNES
 
+=head1 CONTRIBUTORS
+
+=for stopwords Hans Dieter Pearcey Ricardo SIGNES Signes
+
+=over 4
+
+=item *
+
+Hans Dieter Pearcey <hdp@cpan.org>
+
+=item *
+
+Ricardo SIGNES <rjbs@codesimply.com>
+
+=item *
+
+Ricardo SIGNES <rjbs@cpan.org>
+
+=item *
+
+Ricardo Signes <rjbs@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2005 by Ricardo SIGNES.
